@@ -1,19 +1,17 @@
-package # hide from PAUSE 
-    DBICTest::Schema::TreeLike;
+package DBICTest::Schema::TreeLike;
 
-use base qw/DBIx::Class::Core/;
+use base qw/DBIx::Class/;
+
+__PACKAGE__->load_components(qw/PK::Auto::SQLite Core/);
 
 __PACKAGE__->table('treelike');
 __PACKAGE__->add_columns(
   'id' => { data_type => 'integer', is_auto_increment => 1 },
   'parent' => { data_type => 'integer' },
-  'name' => { data_type => 'varchar',
-    size      => 100,
- },
+  'name' => { data_type => 'varchar' },
 );
 __PACKAGE__->set_primary_key(qw/id/);
 __PACKAGE__->belongs_to('parent', 'TreeLike',
                           { 'foreign.id' => 'self.parent' });
-__PACKAGE__->has_many('children', 'TreeLike', { 'foreign.parent' => 'self.id' });
 
 1;
